.. _parser-tree:

Parser Tree
===========

Usage
-----

.. automodule:: parso.python
    :members:
    :undoc-members:


Parser Tree Base Class
----------------------

All nodes and leaves have these methods/properties:

.. autoclass:: parso.tree.NodeOrLeaf
    :members:
    :undoc-members:


Python Parser Tree
------------------

.. automodule:: parso.python.tree
    :members:
    :undoc-members:
    :show-inheritance:


Utility
-------

.. autofunction:: parso.tree.search_ancestor
